@@ -1,3 +1,3 @@
-#error "/home/espenr/tmp/qt-3.2-espenr-19594/qt/extensions/nsplugin/src/jri.h must be provided by Netscape"
+#error "/home/espenr/tmp/qt-3-espenr-20730/qt/extensions/nsplugin/src/jri.h must be provided by Netscape"
 #error "This file is just a placeholder. Please see the documentation"
 #error "to learn how to obtain the real file"
