@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfontdata_p.h   3.2.1   edited Jul 9 16:46 $
+** $Id: qt/qfontdata_p.h   3.3.1   edited Oct 28 17:34 $
 **
 ** Definition of internal QFontData struct
 **
@@ -86,7 +86,8 @@ struct QFontDef
     uint stretch    : 12; // 0-400
 
     uint ignorePitch : 1;
-    uint reserved   : 15; // for future extensions
+    uint fixedPitchComputed : 1; // for Mac OS X only
+    uint reserved   : 14; // for future extensions
 
     bool operator==( const QFontDef &other ) const;
     inline bool operator<( const QFontDef &other ) const
@@ -240,7 +241,11 @@ public:
     QFontEngine *findEngine( const Key &key );
     void insertEngine( const Key &key, QFontEngine *engine );
 
-private:
+#if defined(Q_WS_WIN) || defined(Q_WS_QWS)
+    void cleanupPrinterFonts();
+#endif
+
+    private:
     void increaseCost( uint cost );
     void decreaseCost( uint cost );
     void timerEvent( QTimerEvent *event );
