@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfontengine_p.h   3.2.2   edited Aug 26 22:25 $
+** $Id: qt/qfontengine_p.h   3.3.1   edited Jan 7 11:28 $
 **
 ** ???
 **
@@ -31,7 +31,9 @@
 #ifndef QFONTENGINE_P_H
 #define QFONTENGINE_P_H
 
+#ifndef QT_H
 #include "qglobal.h"
+#endif // QT_H
 
 #ifdef Q_WS_WIN
 #include "qt_windows.h"
@@ -158,7 +160,7 @@ class QGfx;
 class QFontEngine : public QShared
 {
 public:
-    QFontEngine( const QFontDef& );
+    QFontEngine( const QFontDef&, const QPaintDevice * = 0 );
    ~QFontEngine();
     /*QMemoryManager::FontID*/ void *handle() const;
 
@@ -215,6 +217,7 @@ public:
     /*QMemoryManager::FontID*/ void *id;
     int cache_cost;
     int cache_count;
+    int scale;
 };
 #endif // WIN || X11 || MAC
 
@@ -295,7 +298,8 @@ struct TransformedFont
 };
 
 #ifndef QT_NO_XFTFREETYPE
-#include <freetype/freetype.h>
+#include <ft2build.h>
+#include FT_FREETYPE_H
 #include "ftxopen.h"
 
 class QTextCodec;
@@ -501,8 +505,10 @@ private:
 #endif // QT_NO_XFTFREETYPE
 
 #elif defined( Q_WS_MAC )
-
 #include "qt_mac.h"
+#include <qmap.h>
+#include <qcache.h>
+
 class QFontEngineMac : public QFontEngine
 {
 #if 0
@@ -510,9 +516,10 @@ class QFontEngineMac : public QFontEngine
 #else
     FontInfo *info;
 #endif
-    short fnum;
     int psize;
+    short fnum;
     QMacFontInfo *internal_fi;
+    mutable ATSUTextLayout mTextLayout;
     enum { widthCacheSize = 0x500 };
     mutable unsigned char widthCache[widthCacheSize];
     friend class QFont;
@@ -522,6 +529,7 @@ class QFontEngineMac : public QFontEngine
 
 public:
     QFontEngineMac();
+    ~QFontEngineMac();
 
     Error stringToCMap( const QChar *str, int len, glyph_t *glyphs, advance_t *advances, int *nglyphs, bool mirrored ) const;
 
@@ -580,6 +588,9 @@ public:
     bool canRender( const QChar *string,  int len );
 
     Type type() const;
+
+    enum { widthCacheSize = 0x800, cmapCacheSize = 0x500 };
+    unsigned char widthCache[widthCacheSize];
 };
 
 #if 0
