@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qrichtext_p.h   3.2.2   edited Jul 14 13:22 $
+** $Id: qt/qrichtext_p.h   3.3.1   edited Nov 11 13:33 $
 **
 ** Definition of internal rich text classes
 **
@@ -71,7 +71,6 @@
 #include "qpainter.h"
 #include "qlayout.h"
 #include "qobject.h"
-#include "private/qcomplextext_p.h"
 #include "qapplication.h"
 #endif // QT_H
 
@@ -166,7 +165,6 @@ private:
     }
     QTextStringChar( const QTextStringChar & ) {
     }
-    friend class QComplexText;
     friend class QTextParagraph;
 };
 
@@ -187,15 +185,8 @@ public:
     static QString toString( const QMemArray<QTextStringChar> &data );
     QString toString() const;
 
-#if defined(Q_STRICT_INLINING_RULES)
-    // This is for the IRIX MIPSpro o32 ABI - it fails, claiming the
-    // implementation to be a redefinition.
-    inline QTextStringChar &at( int i ) const;
-    inline int length() const;
-#else
-    QTextStringChar &at( int i ) const;
-    int length() const;
-#endif
+    inline QTextStringChar &at( int i ) const { return data[ i ]; }
+    inline int length() const { return data.size(); }
 
     int width( int idx ) const;
 
@@ -319,13 +310,7 @@ public:
     bool operator==( const QTextCursor &c ) const;
     bool operator!=( const QTextCursor &c ) const { return !(*this == c); }
 
-#if defined(Q_STRICT_INLINING_RULES)
-    // This is for the IRIX MIPSpro o32 ABI - it fails, claiming the
-    // implementation to be a redefinition.
-    inline QTextParagraph *paragraph() const;
-#else
-    QTextParagraph *paragraph() const;
-#endif
+    inline QTextParagraph *paragraph() const { return para; }
 
     QTextDocument *document() const;
     int index() const;
@@ -393,7 +378,7 @@ private:
     void gotoIntoNested( const QPoint &globalPos );
 
     QTextParagraph *para;
-    int idx, tmpIndex;
+    int idx, tmpX;
     int ox, oy;
     QValueStack<int> indices;
     QValueStack<QTextParagraph*> paras;
@@ -1138,53 +1123,14 @@ struct Q_EXPORT QTextParagraphSelection
 struct Q_EXPORT QTextLineStart
 {
     QTextLineStart() : y( 0 ), baseLine( 0 ), h( 0 )
-#ifndef QT_NO_COMPLEXTEXT
-	, bidicontext( 0 )
-#endif
     {  }
     QTextLineStart( int y_, int bl, int h_ ) : y( y_ ), baseLine( bl ), h( h_ ),
 	w( 0 )
-#ifndef QT_NO_COMPLEXTEXT
-	, bidicontext( 0 )
-#endif
     {  }
-#ifndef QT_NO_COMPLEXTEXT
-    QTextLineStart( QBidiContext *c, QBidiStatus s ) : y(0), baseLine(0), h(0),
-	status( s ), bidicontext( c ) { if ( bidicontext ) bidicontext->ref(); }
-#endif
-
-    virtual ~QTextLineStart()
-    {
-#ifndef QT_NO_COMPLEXTEXT
-	if ( bidicontext && bidicontext->deref() )
-	    delete bidicontext;
-#endif
-    }
-
-#ifndef QT_NO_COMPLEXTEXT
-    void setContext( QBidiContext *c ) {
-	if ( c == bidicontext )
-	    return;
-	if ( bidicontext && bidicontext->deref() )
-	    delete bidicontext;
-	bidicontext = c;
-	if ( bidicontext )
-	    bidicontext->ref();
-    }
-    QBidiContext *context() const { return bidicontext; }
-#endif
 
 public:
     int y, baseLine, h;
-#ifndef QT_NO_COMPLEXTEXT
-    QBidiStatus status;
-#endif
     int w;
-
-private:
-#ifndef QT_NO_COMPLEXTEXT
-    QBidiContext *bidicontext;
-#endif
 };
 
 #if defined(Q_TEMPLATEDLL)
@@ -1234,13 +1180,10 @@ public:
 //     void setFormat( QTextFormat *fm );
 //     QTextFormat *paragFormat() const;
 
-#if defined(Q_STRICT_INLINING_RULES)
-    // This is for the IRIX MIPSpro o32 ABI - it fails, claiming the
-    // implementation to be a redefinition.
-    inline QTextDocument *document() const;
-#else
-    QTextDocument *document() const;
-#endif
+    inline QTextDocument *document() const {
+	if (hasdoc) return (QTextDocument*) docOrPseudo;
+	return 0;
+    }
     QTextParagraphPseudoDocument *pseudoDocument() const;
 
     QRect rect() const;
@@ -1417,7 +1360,7 @@ private:
     QPtrList<QTextCustomItem> *mFloatingItems;
 #endif
     short utm, ubm, ulm, urm, uflm, ulinespacing;
-    short tabStopWidth;
+    short tabStopWidth, minwidth;
     int *tArray;
     QTextParagraphData *eData;
     short list_val;
@@ -1559,6 +1502,7 @@ public:
     QTextFormat& operator=( const QTextFormat &fm );
     QColor color() const;
     QFont font() const;
+    QFontMetrics fontMetrics() const { return fm; }
     bool isMisspelled() const;
     VerticalAlignment vAlign() const;
     int minLeftBearing() const;
@@ -1692,11 +1636,6 @@ public:
 
 // +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
-inline int QTextString::length() const
-{
-    return data.size();
-}
-
 inline int QTextParagraph::length() const
 {
     return str->length();
@@ -1707,11 +1646,6 @@ inline QRect QTextParagraph::rect() const
     return r;
 }
 
-inline QTextParagraph *QTextCursor::paragraph() const
-{
-    return para;
-}
-
 inline int QTextCursor::index() const
 {
     return idx;
@@ -1965,16 +1899,6 @@ inline bool QTextFormat::useLinkColor() const
     return linkColor;
 }
 
-
-// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-
-inline QTextStringChar &QTextString::at( int i ) const
-{
-    return data[ i ];
-}
-
-// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-
 inline QTextStringChar *QTextParagraph::at( int i ) const
 {
     return &str->at( i );
@@ -2069,13 +1993,6 @@ inline QTextString *QTextParagraph::string() const
     return str;
 }
 
-inline QTextDocument *QTextParagraph::document() const
-{
-    if ( hasdoc )
-	return (QTextDocument*) docOrPseudo;
-    return 0;
-}
-
 inline QTextParagraphPseudoDocument *QTextParagraph::pseudoDocument() const
 {
     if ( hasdoc )
